package gestionClinica;

/**
 * Las <b>Citas</b> tienen una hora y fecha determinadas. Para un mejor control
 * de estas, se ha creado la clase <b>HorarioCita</b> donde cada <i>hora</i>
 * y <i>fecha</i> posible se tratan como una entidad, siendo objetos únicos e irrepetibles.
 * <br><br>
 * Puesto que en cada hora se pueden producir tres <b>Citas</b> simultáneas, estas
 * serán almacenadas en un array de tres posiciones.<br>Se usará una variable de tipo entero
 * para contar las citas concertadas. De este modo se podrá saber de forma más rápida cosas
 * como en que posicion del array se ha de insertar la próxima <b>Cita</b>, si existe espacio para
 * una nueva <b>Cita</b>, etc..  
 * 
 * @author Kabuto
 * @version 08/2019
 */
public class HorarioCita {

	private String fecha;
	private String hora;
	private Cita[] citas;
	private int numCitas;
	
	public HorarioCita(String fecha, String hora) {
		this.fecha = fecha;
		this.hora = hora;
		citas = new Cita[3];
		numCitas = 0;
	}
	
	/**
	 * Informa de si este horario está ya completo y 
	 * por lo tanto no es posible concertar más <b>Citas</b>
	 * @return <b>true</b> el horario está completo,
	 * <b>false</b> aún queda espacio para otra <b>Cita</b>
	 */
	public boolean horarioEstaCompleto() {
		return numCitas == 3;
	}
	
	public void addCita(Cita cita) {
		if (numCitas < 3) {
			citas[numCitas] = cita;
			numCitas++;
		}
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("\nHorario: " + fecha + " - " + hora);
		sb.append("\nCitas concertadas:");
		if (numCitas == 0)
			sb.append("--- No hay Citas ---");
		else {
			for (int i = 0; i < numCitas; i++)
				sb.append("\n#" + i + ": " + citas[i]);
		}
		return sb.toString();
	}
	
	/**
	 * Construye una linea de texto para ser escrita en un archivo en disco.<br>
	 * El formato está diseñado para que cuando el programa la lea para recuperar
	 * la información, sea sencillo distinguir los valores de cada atributo.
	 * @return <b>String</b> para grabar en archivo de texto.
	 */
	public String toLineaFichero() {
		StringBuilder sb = new StringBuilder();
		sb.append(fecha + "<>" + hora + "<>" + numCitas + "\n");
		for (int i = 0; i < numCitas; i++)
			sb.append(citas[i].getCedulaPaciente() + "<>" + citas[i].getNumeroPsicologo() + "\n");
		
		return sb.toString();
	}
	
}
