package gestionClinica;

import java.util.ArrayList;

/**
 * Clase que modela la representación de un <b>Paciente</b> de la clínica.<br>
 * Además de los atributos típicos para identificar a una persona, guarda la fecha
 * de la próxima <b>Cita</b> que pueda tener concertada, el número de <b>Psicólogo</b>
 * asignado y un ArrayList con todos los <b>Expedientes</b> históricos.
 * 
 * @author Kabuto
 * @version 08/2019
 */
public class Paciente {

	private String cedula;
	private String nombre;
	private String telefono;
	private String eMail;
	private String horarioCita;
	private String psicologoAsignado;
	private ArrayList<Expediente> expedientes;
	 
	public Paciente(String cedula, String nombre, String telefono, String eMail) {
		this.cedula = cedula;
		this.nombre = nombre;
		this.telefono = telefono;
		this.eMail = eMail;
		horarioCita = null;
		psicologoAsignado = null;
		expedientes = new ArrayList<Expediente>();
	}

	public String getCedula() {
		return cedula;
	}

	public void setCedula(String cedula) {
		this.cedula = cedula;
	}

	public String getNombre() {
		return nombre;
	}

	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	public String getTelefono() {
		return telefono;
	}

	public void setTelefono(String telefono) {
		this.telefono = telefono;
	}

	public String geteMail() {
		return eMail;
	}

	public void seteMail(String eMail) {
		this.eMail = eMail;
	}

	public String getHorarioCita() {
		return horarioCita;
	}

	public void setHorarioCita(String horarioCita) {
		this.horarioCita = horarioCita;
	}

	public String getPsicologoAsignado() {
		return psicologoAsignado;
	}

	public void setPsicologoAsignado(String psicologoAsignado) {
		this.psicologoAsignado = psicologoAsignado;
	}
	
	public void addExpediente(Expediente exp) {
		expedientes.add(exp);
	}
	
	public void listarExpediente() {
		System.out.println("\t\tExpediente del Paciente");
		System.out.println("\t\t---------- --- --------");
		if (expedientes.isEmpty())
			System.out.println("--- No hay datos que mostrar ---");
		else
			for (Expediente exp: expedientes)
				System.out.println(exp);
	}
	
	@Override
	public boolean equals(Object objeto) {
		if (objeto instanceof Paciente) {
			Paciente otroPaciente = (Paciente)objeto;
			return cedula.equals(otroPaciente.getCedula());
		}
		else
			return false;
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("\nCédula: " + cedula);
		sb.append("\nNombre: " + nombre);
		sb.append("\nTeléfono: " + telefono);
		sb.append("\nE-Mail: " + eMail);
		sb.append("\nPróxima Cita: ");
		if (horarioCita == null)
			sb.append("Sin cita asignada");
		else
			sb.append(horarioCita);
		sb.append("\nPsicólogo Asignado: " + psicologoAsignado);
		return sb.toString();
	}
	
	/**
	 * Construye una linea de texto para ser escrita en un archivo en disco.<br>
	 * El formato está diseñado para que cuando el programa la lea para recuperar
	 * la información, sea sencillo distinguir los valores de cada atributo.
	 * @return <b>String</b> para grabar en archivo de texto.
	 */
	public String toLineaFichero() {
		StringBuilder sb = new StringBuilder();
		//Primera linea: atributos paciente
		sb.append("paciente<>" + cedula + "<>" + nombre + "<>" + telefono + "<>" + eMail +
				"<>" + horarioCita + "<>" + psicologoAsignado + "\n");
		//Segunda linea: longitud del expediente
		sb.append("expediente<>" + expedientes.size() + "\n");
		//Siguientes lineas: expedientes existentes
		for (Expediente exp: expedientes)
			sb.append(exp.toLineaFichero());
		
		return sb.toString();
	}
}
